# Isostatic
A repository for designing isostatic structures

# Descripción
Un repositorio para diseño de estructuras isostaticas mediante un paquete de python. 

# Licencia
Vea el archivo licencia en [github](https://github.com/Rodrigo-A-Jimenez/Isostatic)

# Modulos
- Point (2D)
- Support (vertical, horizontal, momentos)
- rotations (Solo casos de carga lineal)

# Instalacion
```python
pip install isostatic
```

Una vez instalado importe los modulos

```python
from isostatic import Point, Support, LinealLoad, GeneralLoadLineal
```


